# vs-deband, a collection of wrappers and functions for debanding

For further support, drop by `#vsdeband` in the [IEW Discord server](https://discord.gg/qxTxVJGtst).

## How to install

Install `vsdeband` with the following command:

```sh
pip install vsdeband
```

Or if you want the latest git version, install it with this command:

```sh
pip install git+https://github.com/Irrational-Encoding-Wizardry/vs-deband.git
```
<br>